@@ -87,40 +87,79 @@ test_that("ppc_intervals_data does math correctly", {
 
 test_that("ppc_intervals renders correctly", {
   testthat::skip_on_cran()
+  testthat::skip_if_not_installed("vdiffr")
 
   p_base <- ppc_intervals(vdiff_y, vdiff_yrep)
-  vdiffr::expect_doppelganger("ppc intervals (default)", p_base)
+  vdiffr::expect_doppelganger("ppc_intervals (default)", p_base)
 
   p_x <- ppc_intervals(vdiff_y, vdiff_yrep, x = vdiff_y)
-  vdiffr::expect_doppelganger("ppc intervals (x values)", p_x)
+  vdiffr::expect_doppelganger("ppc_intervals (x values)", p_x)
 
   p_50 <- ppc_intervals(vdiff_y, vdiff_yrep, prob = .50)
-  vdiffr::expect_doppelganger("ppc intervals (interval width)", p_50)
+  vdiffr::expect_doppelganger("ppc_intervals (interval width)", p_50)
 })
 
 test_that("ppc_intervals_grouped renders correctly", {
   testthat::skip_on_cran()
+  testthat::skip_if_not_installed("vdiffr")
 
   p_base <- ppc_intervals_grouped(vdiff_y, vdiff_yrep, group = vdiff_group)
-  vdiffr::expect_doppelganger("ppc intervals grouped (default)", p_base)
+  vdiffr::expect_doppelganger("ppc_intervals_grouped (default)", p_base)
 
   p_x <- ppc_intervals_grouped(
     y = vdiff_y,
     yrep = vdiff_yrep,
     x = vdiff_y,
     group = vdiff_group)
-  vdiffr::expect_doppelganger("ppc intervals grouped (x values)", p_x)
+  vdiffr::expect_doppelganger("ppc_intervals_grouped (x values)", p_x)
 })
 
 test_that("ppc_ribbon renders correctly", {
   testthat::skip_on_cran()
+  testthat::skip_if_not_installed("vdiffr")
 
   p_base <- ppc_ribbon(vdiff_y, vdiff_yrep)
-  vdiffr::expect_doppelganger("ppc ribbon (default)", p_base)
+  vdiffr::expect_doppelganger("ppc_ribbon (default)", p_base)
 
   p_x <- ppc_ribbon(vdiff_y, vdiff_yrep, x = vdiff_y)
-  vdiffr::expect_doppelganger("ppc ribbon (x values)", p_x)
+  vdiffr::expect_doppelganger("ppc_ribbon (x values)", p_x)
 
   p_50 <- ppc_ribbon(vdiff_y, vdiff_yrep, prob = 0.5)
-  vdiffr::expect_doppelganger("ppc ribbon (interval width)", p_50)
+  vdiffr::expect_doppelganger("ppc_ribbon (interval width)", p_50)
+
+  p_line <- ppc_ribbon(vdiff_y, vdiff_yrep, y_draw = "line")
+  vdiffr::expect_doppelganger("ppc_intervals (y_draw = line)", p_line)
+
+  p_point <- ppc_ribbon(vdiff_y, vdiff_yrep, y_draw = "point")
+  vdiffr::expect_doppelganger("ppc_intervals (y_draw = point)", p_point)
+
+  p_both <- ppc_ribbon(vdiff_y, vdiff_yrep, y_draw = "both")
+  vdiffr::expect_doppelganger("ppc_intervals (y_draw = both)", p_both)
+})
+
+test_that("ppc_ribbon_grouped renders correctly", {
+  testthat::skip_on_cran()
+  testthat::skip_if_not_installed("vdiffr")
+
+  p_base <- ppc_ribbon_grouped(vdiff_y, vdiff_yrep, group = vdiff_group)
+  vdiffr::expect_doppelganger("ppc_ribbon_grouped (default)", p_base)
+
+  p_line <- ppc_ribbon_grouped(vdiff_y, vdiff_yrep, group = vdiff_group,
+                               y_draw = "line")
+  vdiffr::expect_doppelganger("ppc_ribbon_grouped (y_draw = line)", p_line)
+
+  p_point <- ppc_ribbon_grouped(vdiff_y, vdiff_yrep, group = vdiff_group,
+                               y_draw = "point")
+  vdiffr::expect_doppelganger("ppc_ribbon_grouped (y_draw = point)", p_point)
+
+  p_both <- ppc_ribbon_grouped(vdiff_y, vdiff_yrep, group = vdiff_group,
+                               y_draw = "both")
+  vdiffr::expect_doppelganger("ppc_ribbon_grouped (y_draw = both)", p_both)
+
+  p_x <- ppc_ribbon_grouped(
+    y = vdiff_y,
+    yrep = vdiff_yrep,
+    x = vdiff_y,
+    group = vdiff_group)
+  vdiffr::expect_doppelganger("ppc_ribbon_grouped (x values)", p_x)
 })
